@@ -5,10 +5,14 @@ const path = require('path');
 
 const babel = require('@babel/core');
 
-const { readdirRecursive, showDirStats } = require('./utils');
+const {
+  writeGeneratedFile,
+  readdirRecursive,
+  showDirStats,
+} = require('./utils.js');
 
 if (require.main === module) {
-  fs.rmdirSync('./denoDist', { recursive: true, force: true });
+  fs.rmSync('./denoDist', { recursive: true, force: true });
   fs.mkdirSync('./denoDist');
 
   const srcFiles = readdirRecursive('./src', { ignoreDir: /^__.*__$/ });
@@ -17,12 +21,10 @@ if (require.main === module) {
     const destPath = path.join('./denoDist', filepath);
 
     fs.mkdirSync(path.dirname(destPath), { recursive: true });
-    if (filepath.endsWith('.js')) {
+    if (filepath.endsWith('.ts')) {
       const options = { babelrc: false, configFile: './.babelrc-deno.json' };
       const output = babel.transformFileSync(srcPath, options).code + '\n';
-      fs.writeFileSync(destPath, output);
-    } else if (filepath.endsWith('.d.ts')) {
-      fs.copyFileSync(srcPath, destPath);
+      writeGeneratedFile(destPath, output);
     }
   }
 
